package com.fs.hospital.service;

import java.util.List;
import com.fs.hospital.domain.HospitalTreatItem;

/**
 * 治疗Service接口
 * 
 * @author fs
 * @date 2024-03-26
 */
public interface IHospitalTreatItemService 
{
    /**
     * 查询治疗
     * 
     * @param treatId 治疗主键
     * @return 治疗
     */
    public HospitalTreatItem selectHospitalTreatItemByTreatId(Long treatId);

    /**
     * 查询治疗列表
     * 
     * @param hospitalTreatItem 治疗
     * @return 治疗集合
     */
    public List<HospitalTreatItem> selectHospitalTreatItemList(HospitalTreatItem hospitalTreatItem);

    /**
     * 新增治疗
     * 
     * @param hospitalTreatItem 治疗
     * @return 结果
     */
    public int insertHospitalTreatItem(HospitalTreatItem hospitalTreatItem);

    /**
     * 修改治疗
     * 
     * @param hospitalTreatItem 治疗
     * @return 结果
     */
    public int updateHospitalTreatItem(HospitalTreatItem hospitalTreatItem);

    /**
     * 批量删除治疗
     * 
     * @param treatIds 需要删除的治疗主键集合
     * @return 结果
     */
    public int deleteHospitalTreatItemByTreatIds(Long[] treatIds);

    /**
     * 删除治疗信息
     * 
     * @param treatId 治疗主键
     * @return 结果
     */
    public int deleteHospitalTreatItemByTreatId(Long treatId);
}
